==> ochusha-0.5.2.tar.gz: ochusha-0.5.2/gtk2/threadlist_view.h <==
/*
 * Copyright (c) 2003-2004 The Ochusha Project.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 * $Id: threadlist_view.h,v 1.36 2004/02/05 01:05:46 fuyu Exp $
 */

#ifndef _THREADLIST_VIEW_H_
#define _THREADLIST_VIEW_H_

#include "ochusha.h"

#include "ochusha_bbs_thread.h"

#include <gtk/gtk.h>

#ifdef __cplusplus
extern "C" {
#endif


#define THREADLIST_VIEW_TYPE			(threadlist_view_get_type())
#define THREADLIST_VIEW(obj)			(G_TYPE_CHECK_INSTANCE_CAST((obj), THREADLIST_VIEW_TYPE, ThreadlistView))
#define THREADLIST_VIEW_CLASS(klass)		(G_TYPE_CHECK_CLASS_CAST((klass), THREADLIST_VIEW_TYPE, ThreadlistViewClass))
#define IS_THREADLIST_VIEW(obj)			(G_TYPE_CHECK_INSTANCE_TYPE((obj), THREADLIST_VIEW_TYPE))
#define IS_THREADLIST_VIEW_CLASS(klass)		(G_TYPE_CHECK_CLASS_TYPE((klass), THREADLIST_VIEW_TYPE))
#define THREADLIST_VIEW_GET_CLASS(obj)		(G_TYPE_INSTANCE_GET_CLASS((obj), THREADLIST_VIEW_TYPE, ThreadlistViewClass))


typedef struct _ThreadlistView ThreadlistView;
typedef struct _ThreadlistViewClass ThreadlistViewClass;


/*
 * Υˡѥ᡼
 */
typedef enum
{
  THREADLIST_SORT_BY_NONE,
  THREADLIST_SORT_BY_BOARD,
  THREADLIST_SORT_BY_RANK,
  THREADLIST_SORT_BY_MARK,
  THREADLIST_SORT_BY_TITLE,
  THREADLIST_SORT_BY_N_RESPONSES,
  THREADLIST_SORT_BY_N_RESPONSES_GOT,
  THREADLIST_SORT_BY_N_RESPONSES_UNREAD,
  THREADLIST_SORT_BY_N_RESPONSES_UNGOT,
  THREADLIST_SORT_BY_N_RESPONSES_VERBOSE,
  THREADLIST_SORT_BY_LAST_MODIFIED,
  THREADLIST_SORT_BY_WEIGHT
} ThreadlistViewSortMode;


struct _ThreadlistView
{
  GtkTreeView view;

  GtkTreeModel *model;

  GtkTreeViewColumn *board_column;
  GtkTreeViewColumn *rank_column;
  GtkTreeViewColumn *mark_column;
  GtkTreeViewColumn *title_column;
  GtkTreeViewColumn *n_res_column;
  GtkTreeViewColumn *n_got_column;
  GtkTreeViewColumn *n_ungot_column;
  GtkTreeViewColumn *n_shown_column;
  GtkTreeViewColumn *n_unread_column;
  GtkTreeViewColumn *n_res_verbose_column;
  GtkTreeViewColumn *rank_diff_column;
  GtkTreeViewColumn *last_modified_column;
  GtkTreeViewColumn *weight_column;

  GtkTreeViewColumn *current_sort_column;
  ThreadlistViewSortMode sort_mode;

  GtkTreeSelection *selection;

  GtkTreePath *last_event_path;

  gboolean remove_hidden_thread;
  gboolean editable;
  gboolean default_open_in_tab;

  /* Ϣ */
  gboolean (*title_match_func)(const gchar *title, gpointer search_data);
  int last_search_position;
  int number_of_rows;

  int count;
  int last_rank_diff;

  OchushaBBSThread *recently_pointed_thread;

  guint view_is_initialized	: 1;
  guint model_is_opened		: 1;
  guint use_native_search	: 1;
  guint being_searched		: 1;
};


typedef enum {
  THREADLIST_SEARCH_DIRECTION_FORWARD,
  THREADLIST_SEARCH_DIRECTION_BACKWARD
} ThreadlistSearchDirection;


typedef enum {
  THREADLIST_SEARCH_ACTION_FORWARD,
  THREADLIST_SEARCH_ACTION_BACKWARD,
  THREADLIST_SEARCH_ACTION_REGEXP_FORWARD,
  THREADLIST_SEARCH_ACTION_REGEXP_BACKWARD,
  THREADLIST_SEARCH_ACTION_TERMINATE
} ThreadlistSearchAction;


struct _ThreadlistViewClass
{
  GtkTreeViewClass parent_class;

  void (*open_thread_view)(ThreadlistView *threadlist_view,
			   OchushaBBSThread *thread,
			   gboolean in_tab, gboolean with_browser,
			   gboolean fake_relation);

  void (*thread_mouse_over)(ThreadlistView *threadlist_view,
			    OchushaBBSThread *thread);
  void (*thread_mouse_out)(ThreadlistView *threadlist_view,
			   OchushaBBSThread *thread);

  void (*toggle_mark)(ThreadlistView *threadlist_view,
		      OchushaBBSThread *thread);
  void (*toggle_hide)(ThreadlistView *threadlist_view,
		      OchushaBBSThread *thread);
  void (*bookmark_thread)(ThreadlistView *threadlist_view,
			  OchushaBBSThread *thread);
  void (*mark_thread)(ThreadlistView *threadlist_view,
		      OchushaBBSThread *thread, gboolean do_mark);
  void (*reset_thread)(ThreadlistView *threadlist_view,
		       OchushaBBSThread *thread);
  void (*kill_thread)(ThreadlistView *threadlist_view,
		      OchushaBBSThread *thread);
  void (*copy_thread_url)(ThreadlistView *threadlist_view,
			  OchushaBBSThread *thread);
  gboolean (*advance_view)(ThreadlistView *threadlist_view,
			   OchushaBBSThread *thread);
  gboolean (*back_view)(ThreadlistView *threadlist_view,
			OchushaBBSThread *thread);
  void (*write_response)(ThreadlistView *threadlist_view,
			 OchushaBBSThread *thread);

  void (*close_threadlist)(ThreadlistView *threadlist_view);
  gboolean (*interactive_search)(ThreadlistView *threadlist_view,
				 ThreadlistSearchAction search_action);

  void (*do_on_selection)(ThreadlistView *threadlist_view, int what_to_do);
  void (*do_on_thread_at_cursor)(ThreadlistView *threadlist_view,
				 int what_to_do);
};


/*
 * ˤ륨ȥθɤѥ᡼
 */
typedef enum
{
  THREADLIST_ENTRY_FLAG_MARK = 		1 << 0,		/* ˥å */
  THREADLIST_ENTRY_FLAG_STRIKE = 	1 << 1,		/* ä */
} ThreadlistEntryVisualFlags;


typedef enum
{
  LIST_ENTRY_FOREGROUND_NORMAL = 0,
  LIST_ENTRY_FOREGROUND_EMPH,
  LIST_ENTRY_FOREGROUND_STRONG,
  LIST_ENTRY_FOREGROUND_HIDDEN,
  NUMBER_OF_LIST_ENTRY_FOREGROUND_COLORS
} ThreadlistEntryForeground;


typedef enum
{
  LIST_ENTRY_BACKGROUND_NORMAL = 0,
  LIST_ENTRY_BACKGROUND_EMPH,
  LIST_ENTRY_BACKGROUND_STRONG,
  LIST_ENTRY_BACKGROUND_HIDDEN,
  NUMBER_OF_LIST_ENTRY_BACKGROUND_COLORS,
} ThreadlistEntryBackground;


typedef struct _ThreadlistEntryVisualParameter
{
  guint flags			: 2;	/* ThreadlistEntryVisualFlagsOR */

  guint foreground_color	: 4;	/* ThreadlistEntryForeground */
  guint background_color	: 4;	/* ThreadlistEntryBackground */

  guint reserved		: 22;
} ThreadlistEntryVisualParameter;


#define THREADLIST_ENTRY_VISUAL_FLAGS_WIDTH		2
#define THREADLIST_ENTRY_VISUAL_FOREGROUND_COLOR_WIDTH	4
#define THREADLIST_ENTRY_VISUAL_BACKGROUND_COLOR_WIDTH	4


GType threadlist_view_get_type(void);
GtkWidget *threadlist_view_new(void);
gboolean threadlist_view_get_remove_hidden_thread(ThreadlistView *view);
void threadlist_view_set_remove_hidden_thread(ThreadlistView *view,
					      gboolean remove);
gboolean threadlist_view_get_editable(ThreadlistView *view);
void threadlist_view_set_editable(ThreadlistView *view, gboolean editable);
void threadlist_entry_set_foreground_color(ThreadlistEntryForeground color,
					   const char *color_name);
void threadlist_entry_set_background_color(ThreadlistEntryBackground color,
					   const char *color_name);

gboolean threadlist_view_get_default_open_in_tab(ThreadlistView *view);
void threadlist_view_set_default_open_in_tab(ThreadlistView *view,
					     gboolean default_open_in_tab);

void threadlist_view_set_sort_mode(ThreadlistView *view,
				   ThreadlistViewSortMode mode);

void threadlist_view_append_board(ThreadlistView *view);
void threadlist_view_append_rank(ThreadlistView *view);
void threadlist_view_append_mark(ThreadlistView *view);
void threadlist_view_append_title(ThreadlistView *view);
void threadlist_view_append_number_of_responses(ThreadlistView *view);
void threadlist_view_append_number_of_responses_got(ThreadlistView *view);
void threadlist_view_append_number_of_responses_ungot(ThreadlistView *view);
void threadlist_view_append_number_of_responses_shown(ThreadlistView *view);
void threadlist_view_append_number_of_responses_unread(ThreadlistView *view);
void threadlist_view_append_number_of_responses_verbose(ThreadlistView *view);
void threadlist_view_append_rank_difference(ThreadlistView *view);
void threadlist_view_append_last_modified(ThreadlistView *view);
void threadlist_view_append_weight(ThreadlistView *view);

void threadlist_view_initialize_default_view(ThreadlistView *view);

gboolean threadlist_view_open(ThreadlistView *view);
void threadlist_view_close(ThreadlistView *view);
void threadlist_view_show(ThreadlistView *view);
void threadlist_view_freeze(ThreadlistView *view);
void threadlist_view_chew(ThreadlistView *view);
void threadlist_view_append_thread(ThreadlistView *view,
				   OchushaBBSThread *thread,
				   int num_shown, int num_unread,
				   int last_rank, int new_rank, int weight);
void threadlist_view_update_thread(ThreadlistView *view,
				   OchushaBBSThread *thread,
				   int num_shown, int num_unread, int weight);
void threadlist_view_update_thread_visual(ThreadlistView *view,
				OchushaBBSThread *thread,
				ThreadlistEntryVisualParameter *parameter);
void threadlist_view_remove_thread(ThreadlistView *view,
				   OchushaBBSThread *thread);

void threadlist_view_scroll_to_thread(ThreadlistView *view,
				      OchushaBBSThread *thread);

void threadlist_view_set_enable_native_search(ThreadlistView *view,
					      gboolean enable);
gboolean threadlist_view_get_enable_native_search(ThreadlistView *view);

gboolean threadlist_view_start_interactive_search(ThreadlistView *view);

typedef gboolean (ThreadlistViewTitleMatchFunc)(const gchar *title,
						gpointer search_data);

void threadlist_view_set_title_match_func(ThreadlistView *view,
					  ThreadlistViewTitleMatchFunc *func);
ThreadlistViewTitleMatchFunc *threadlist_view_get_title_match_func(
							ThreadlistView *view);
void threadlist_view_set_being_searched(ThreadlistView *view, gboolean being);
gboolean threadlist_view_find_next(ThreadlistView *view,
				   ThreadlistSearchDirection direction,
				   gboolean enable_wrap,
				   gboolean include_current_pos,
				   gpointer search_data);

void threadlist_entry_set_foreground(ThreadlistEntryForeground color,
				     const char *color_name);

void threadlist_entry_set_background(ThreadlistEntryBackground color,
				     const char *color_name);

#ifdef __cplusplus
} // extern "C"
#endif

#endif	/* _THREADLIST_VIEW_H_ */

==> ochusha_0.5.4.5.orig.tar.gz: ochusha-0.5.4.5/gtk2/threadlist_view.h <==
/*
 * Copyright (c) 2003-2004 The Ochusha Project.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 * $Id: threadlist_view.h,v 1.36.2.1 2004/06/11 12:02:05 fuyu Exp $
 */

#ifndef _THREADLIST_VIEW_H_
#define _THREADLIST_VIEW_H_

#include "ochusha.h"

#include "ochusha_bbs_thread.h"

#include <gtk/gtk.h>

#ifdef __cplusplus
extern "C" {
#endif


#define THREADLIST_VIEW_TYPE			(threadlist_view_get_type())
#define THREADLIST_VIEW(obj)			(G_TYPE_CHECK_INSTANCE_CAST((obj), THREADLIST_VIEW_TYPE, ThreadlistView))
#define THREADLIST_VIEW_CLASS(klass)		(G_TYPE_CHECK_CLASS_CAST((klass), THREADLIST_VIEW_TYPE, ThreadlistViewClass))
#define IS_THREADLIST_VIEW(obj)			(G_TYPE_CHECK_INSTANCE_TYPE((obj), THREADLIST_VIEW_TYPE))
#define IS_THREADLIST_VIEW_CLASS(klass)		(G_TYPE_CHECK_CLASS_TYPE((klass), THREADLIST_VIEW_TYPE))
#define THREADLIST_VIEW_GET_CLASS(obj)		(G_TYPE_INSTANCE_GET_CLASS((obj), THREADLIST_VIEW_TYPE, ThreadlistViewClass))

#define THREADLIST_VIEW_ACTION_TYPE		(threadlist_view_action_get_type())


typedef enum
{
  BOOKMARK_THREAD,
  MARK_THREAD,
  UNMARK_THREAD,
  TOGGLE_THREAD_HIDDEN_STATE,
  KILL_THREAD,
  ADVANCE_THREAD_VIEW,
  BACK_THREAD_VIEW,
  WRITE_RESPONSE,
  OPEN_FAKE_RELATION,
} ThreadlistViewAction;


GType threadlist_view_action_get_type(void) G_GNUC_CONST;


typedef struct _ThreadlistView ThreadlistView;
typedef struct _ThreadlistViewClass ThreadlistViewClass;


/*
 * Υˡѥ᡼
 */
typedef enum
{
  THREADLIST_SORT_BY_NONE,
  THREADLIST_SORT_BY_BOARD,
  THREADLIST_SORT_BY_RANK,
  THREADLIST_SORT_BY_MARK,
  THREADLIST_SORT_BY_TITLE,
  THREADLIST_SORT_BY_N_RESPONSES,
  THREADLIST_SORT_BY_N_RESPONSES_GOT,
  THREADLIST_SORT_BY_N_RESPONSES_UNREAD,
  THREADLIST_SORT_BY_N_RESPONSES_UNGOT,
  THREADLIST_SORT_BY_N_RESPONSES_VERBOSE,
  THREADLIST_SORT_BY_LAST_MODIFIED,
  THREADLIST_SORT_BY_WEIGHT
} ThreadlistViewSortMode;


struct _ThreadlistView
{
  GtkTreeView view;

  GtkTreeModel *model;

  GtkTreeViewColumn *board_column;
  GtkTreeViewColumn *rank_column;
  GtkTreeViewColumn *mark_column;
  GtkTreeViewColumn *title_column;
  GtkTreeViewColumn *n_res_column;
  GtkTreeViewColumn *n_got_column;
  GtkTreeViewColumn *n_ungot_column;
  GtkTreeViewColumn *n_shown_column;
  GtkTreeViewColumn *n_unread_column;
  GtkTreeViewColumn *n_res_verbose_column;
  GtkTreeViewColumn *rank_diff_column;
  GtkTreeViewColumn *last_modified_column;
  GtkTreeViewColumn *weight_column;

  GtkTreeViewColumn *current_sort_column;
  ThreadlistViewSortMode sort_mode;

  GtkTreeSelection *selection;

  GtkTreePath *last_event_path;

  gboolean remove_hidden_thread;
  gboolean editable;
  gboolean default_open_in_tab;

  /* Ϣ */
  gboolean (*title_match_func)(const gchar *title, gpointer search_data);
  int last_search_position;
  int number_of_rows;

  int count;
  int last_rank_diff;

  OchushaBBSThread *recently_pointed_thread;

  guint view_is_initialized	: 1;
  guint model_is_opened		: 1;
  guint use_native_search	: 1;
  guint being_searched		: 1;
};


typedef enum {
  THREADLIST_SEARCH_DIRECTION_FORWARD,
  THREADLIST_SEARCH_DIRECTION_BACKWARD
} ThreadlistSearchDirection;


typedef enum {
  THREADLIST_SEARCH_ACTION_FORWARD,
  THREADLIST_SEARCH_ACTION_BACKWARD,
  THREADLIST_SEARCH_ACTION_REGEXP_FORWARD,
  THREADLIST_SEARCH_ACTION_REGEXP_BACKWARD,
  THREADLIST_SEARCH_ACTION_TERMINATE
} ThreadlistSearchAction;


struct _ThreadlistViewClass
{
  GtkTreeViewClass parent_class;

  void (*open_thread_view)(ThreadlistView *threadlist_view,
			   OchushaBBSThread *thread,
			   gboolean in_tab, gboolean with_browser,
			   gboolean fake_relation);

  void (*thread_mouse_over)(ThreadlistView *threadlist_view,
			    OchushaBBSThread *thread);
  void (*thread_mouse_out)(ThreadlistView *threadlist_view,
			   OchushaBBSThread *thread);

  void (*toggle_mark)(ThreadlistView *threadlist_view,
		      OchushaBBSThread *thread);
  void (*toggle_hide)(ThreadlistView *threadlist_view,
		      OchushaBBSThread *thread);
  void (*bookmark_thread)(ThreadlistView *threadlist_view,
			  OchushaBBSThread *thread);
  void (*mark_thread)(ThreadlistView *threadlist_view,
		      OchushaBBSThread *thread, gboolean do_mark);
  void (*reset_thread)(ThreadlistView *threadlist_view,
		       OchushaBBSThread *thread);
  void (*kill_thread)(ThreadlistView *threadlist_view,
		      OchushaBBSThread *thread);
  void (*copy_thread_url)(ThreadlistView *threadlist_view,
			  OchushaBBSThread *thread);
  gboolean (*advance_view)(ThreadlistView *threadlist_view,
			   OchushaBBSThread *thread);
  gboolean (*back_view)(ThreadlistView *threadlist_view,
			OchushaBBSThread *thread);
  void (*write_response)(ThreadlistView *threadlist_view,
			 OchushaBBSThread *thread);

  void (*close_threadlist)(ThreadlistView *threadlist_view);
  gboolean (*interactive_search)(ThreadlistView *threadlist_view,
				 ThreadlistSearchAction search_action);

  void (*do_on_selection)(ThreadlistView *threadlist_view, int what_to_do);
  void (*do_on_thread_at_cursor)(ThreadlistView *threadlist_view,
				 ThreadlistViewAction what_to_do);
};


/*
 * ˤ륨ȥθɤѥ᡼
 */
typedef enum
{
  THREADLIST_ENTRY_FLAG_MARK = 		1 << 0,		/* ˥å */
  THREADLIST_ENTRY_FLAG_STRIKE = 	1 << 1,		/* ä */
} ThreadlistEntryVisualFlags;


typedef enum
{
  LIST_ENTRY_FOREGROUND_NORMAL = 0,
  LIST_ENTRY_FOREGROUND_EMPH,
  LIST_ENTRY_FOREGROUND_STRONG,
  LIST_ENTRY_FOREGROUND_HIDDEN,
  NUMBER_OF_LIST_ENTRY_FOREGROUND_COLORS
} ThreadlistEntryForeground;


typedef enum
{
  LIST_ENTRY_BACKGROUND_NORMAL = 0,
  LIST_ENTRY_BACKGROUND_EMPH,
  LIST_ENTRY_BACKGROUND_STRONG,
  LIST_ENTRY_BACKGROUND_HIDDEN,
  NUMBER_OF_LIST_ENTRY_BACKGROUND_COLORS,
} ThreadlistEntryBackground;


typedef struct _ThreadlistEntryVisualParameter
{
  guint flags			: 2;	/* ThreadlistEntryVisualFlagsOR */

  guint foreground_color	: 4;	/* ThreadlistEntryForeground */
  guint background_color	: 4;	/* ThreadlistEntryBackground */

  guint reserved		: 22;
} ThreadlistEntryVisualParameter;


#define THREADLIST_ENTRY_VISUAL_FLAGS_WIDTH		2
#define THREADLIST_ENTRY_VISUAL_FOREGROUND_COLOR_WIDTH	4
#define THREADLIST_ENTRY_VISUAL_BACKGROUND_COLOR_WIDTH	4


GType threadlist_view_get_type(void) G_GNUC_CONST;
GtkWidget *threadlist_view_new(void);
gboolean threadlist_view_get_remove_hidden_thread(ThreadlistView *view);
void threadlist_view_set_remove_hidden_thread(ThreadlistView *view,
					      gboolean remove);
gboolean threadlist_view_get_editable(ThreadlistView *view);
void threadlist_view_set_editable(ThreadlistView *view, gboolean editable);
void threadlist_entry_set_foreground_color(ThreadlistEntryForeground color,
					   const char *color_name);
void threadlist_entry_set_background_color(ThreadlistEntryBackground color,
					   const char *color_name);

gboolean threadlist_view_get_default_open_in_tab(ThreadlistView *view);
void threadlist_view_set_default_open_in_tab(ThreadlistView *view,
					     gboolean default_open_in_tab);

void threadlist_view_set_sort_mode(ThreadlistView *view,
				   ThreadlistViewSortMode mode);

void threadlist_view_append_board(ThreadlistView *view);
void threadlist_view_append_rank(ThreadlistView *view);
void threadlist_view_append_mark(ThreadlistView *view);
void threadlist_view_append_title(ThreadlistView *view);
void threadlist_view_append_number_of_responses(ThreadlistView *view);
void threadlist_view_append_number_of_responses_got(ThreadlistView *view);
void threadlist_view_append_number_of_responses_ungot(ThreadlistView *view);
void threadlist_view_append_number_of_responses_shown(ThreadlistView *view);
void threadlist_view_append_number_of_responses_unread(ThreadlistView *view);
void threadlist_view_append_number_of_responses_verbose(ThreadlistView *view);
void threadlist_view_append_rank_difference(ThreadlistView *view);
void threadlist_view_append_last_modified(ThreadlistView *view);
void threadlist_view_append_weight(ThreadlistView *view);

void threadlist_view_initialize_default_view(ThreadlistView *view);

gboolean threadlist_view_open(ThreadlistView *view);
void threadlist_view_close(ThreadlistView *view);
void threadlist_view_show(ThreadlistView *view);
void threadlist_view_freeze(ThreadlistView *view);
void threadlist_view_chew(ThreadlistView *view);
void threadlist_view_append_thread(ThreadlistView *view,
				   OchushaBBSThread *thread,
				   int num_shown, int num_unread,
				   int last_rank, int new_rank, int weight);
void threadlist_view_update_thread(ThreadlistView *view,
				   OchushaBBSThread *thread,
				   int num_shown, int num_unread, int weight);
void threadlist_view_update_thread_visual(ThreadlistView *view,
				OchushaBBSThread *thread,
				ThreadlistEntryVisualParameter *parameter);
void threadlist_view_remove_thread(ThreadlistView *view,
				   OchushaBBSThread *thread);

void threadlist_view_scroll_to_thread(ThreadlistView *view,
				      OchushaBBSThread *thread);

void threadlist_view_set_enable_native_search(ThreadlistView *view,
					      gboolean enable);
gboolean threadlist_view_get_enable_native_search(ThreadlistView *view);

gboolean threadlist_view_start_interactive_search(ThreadlistView *view);

typedef gboolean (ThreadlistViewTitleMatchFunc)(const gchar *title,
						gpointer search_data);

void threadlist_view_set_title_match_func(ThreadlistView *view,
					  ThreadlistViewTitleMatchFunc *func);
ThreadlistViewTitleMatchFunc *threadlist_view_get_title_match_func(
							ThreadlistView *view);
void threadlist_view_set_being_searched(ThreadlistView *view, gboolean being);
gboolean threadlist_view_find_next(ThreadlistView *view,
				   ThreadlistSearchDirection direction,
				   gboolean enable_wrap,
				   gboolean include_current_pos,
				   gpointer search_data);

void threadlist_entry_set_foreground(ThreadlistEntryForeground color,
				     const char *color_name);

void threadlist_entry_set_background(ThreadlistEntryBackground color,
				     const char *color_name);

#ifdef __cplusplus
} // extern "C"
#endif

#endif	/* _THREADLIST_VIEW_H_ */
